@@ -1,6 +1,5 @@
 from django.template.defaultfilters import register
 from django.utils.translation import ugettext_lazy as _
-from frontend_notification.views import notice_count
 
 
 @register.filter(name='notification_style')
@@ -24,9 +23,3 @@ def notification_status(val):
         return _('new').title()
     else:
         return _('read').title()
-
-
-@register.assignment_tag(name='get_notice_count')
-def get_notice_count(user):
-    """tag to display notice count"""
-    return notice_count(user)
